# cronus

![logo](logo.png)

**cronus** is a Python tool designed to facilitate *Markov Chain Monte Carlo (MCMC)* and *Nested Sampling (NS)*
in large supercomputing clusters.

It relies on the powerful MCMC sampler **zeus** to do the heavy-lifting and incorporates various MPI features
along with a suite of automated *Convergence Diagnostics*. 

``cronus`` is designed to be used via the terminal using parameter files and it is particularly suited for
Astrophysical and Cosmological applications.


## Documentation

Read the docs at [cronus-mcmc.readthedocs.io](https://cronus-mcmc.readthedocs.io)

## Attribution

- Please cite X if you find this code useful in your research.


## Licence

Copyright 2020 Minas Karamanis and contributors.

``cronus`` is free software made available under the GPL-3.0 License.